@@ -53,6 +53,8 @@ class EnhancedJSONEncoder(json.JSONEncoder):
             return list(o)
         if isinstance(o, Decimal):
             return str(o)
+        if isinstance(o, Exception):
+            return repr(o)
         return super().default(o)
 
 
